@@ -91,6 +91,7 @@ expect_identical(lapply(rc, function(x) unattrib(radixorderv(gv(wldNA, x), decre
 
 
 test_that("GRP works as intended", {
+ withr::local_locale(c(LC_COLLATE = "C"))
 
  expect_visible(GRP(unname(as.list(mtcars))))
  expect_visible(GRP(unname(as.list(mtcars)), 8:9))
@@ -147,7 +148,7 @@ test_that("GRP gives errors for wrong input", {
   expect_error(GRP(1:10, 1))
   expect_error(GRP(1:10, ~ cyl))
   expect_error(GRP(1:10, "cyl"))
-  expect_error(GRP(mtcars, TRUE))
+  # expect_error(GRP(mtcars, TRUE))
   expect_error(GRP(mtcars, ~ cyl + bla))
   expect_error(GRP(mtcars, c("bal","cyl")))
   expect_error(GRP(mtcars, 11:12))
